find_case_insensitive_directories

Function find_case_insensitive_directories 

pub fn find_case_insensitive_directories(
    directory: &Path,
    expected_name: &str,
) -> Result<Vec<PathBuf>>
Every subdirectory of directory matching expected_name ASCII case-insensitively.

The directory half of find_case_insensitive_files, with the same reason to prefer it over find_case_insensitive_directory.

Errors

Propagates the io::Error from reading directory or one of its entries.