encode_text

Function encode_text 

pub fn encode_text(
    input: &str,
    encoding: TextEncoding,
) -> Result<Vec<u8>, EncodeTextError>
Encodes Unicode text into bytes using strict lossless behavior.

Errors

EncodeTextError where a character is not representable in encoding, naming the first one and its index. Nothing is substituted.