EncodeTextError

Struct EncodeTextError 

pub struct EncodeTextError {
    pub char_index: usize,
    pub character: char,
    pub encoding: TextEncoding,
}
Error returned when strict text encoding would lose information.

Fields

char_index: usize

Character position (by char index) that could not be encoded.

character: char

Unicode character that is not representable in the target encoding.

encoding: TextEncoding

Target encoding that rejected the character.