pub struct EncodeTextError {
pub char_index: usize,
pub character: char,
pub encoding: TextEncoding,
}Expand description
Error returned when strict text encoding would lose information.
Fields
char_index: usizeCharacter position (by char index) that could not be encoded.
character: charUnicode character that is not representable in the target encoding.
encoding: TextEncodingTarget encoding that rejected the character.